@@ -31,10 +31,12 @@ import javax.xml.namespace.QName;
  * Main configuration class to supply keys etc.
  * This class is subject to change in the future.
  *
+ * @author $Author: coheigea $
+ * @version $Revision: 1817216 $ $Date: 2017-12-05 16:54:49 +0000 (Tue, 05 Dec 2017) $
  */
 public class XMLSecurityProperties {
 
-    private final List<InputProcessor> inputProcessorList = new ArrayList<>();
+    private final List<InputProcessor> inputProcessorList = new ArrayList<InputProcessor>();
     private boolean skipDocumentEvents = false;
     private boolean disableSchemaValidation = false;
 
@@ -67,11 +69,11 @@ public class XMLSecurityProperties {
 
     private Key signatureVerificationKey;
 
-    private int signaturePosition;
+    private int signaturePosition = 0;
 
     private QName idAttributeNS = XMLSecurityConstants.ATT_NULL_Id;
 
-    private final Map<String, Key> keyNameMap = new HashMap<>();
+    private final Map<String, Key> keyNameMap = new HashMap<String, Key>();
 
     private boolean signatureGenerateIds = true;
     private boolean signatureIncludeDigestTransform = true;
@@ -154,10 +156,10 @@ public class XMLSecurityProperties {
         this.signaturePosition = signaturePosition;
     }
 
-    /**
+    /** 
      * Return the qualified name of the ID attribute used to sign the document.
      * By default, ID is used.
-     *
+     * 
      * @return the qualified name of the ID attribute
      */
     public QName getIdAttributeNS() {
