@@ -54,15 +54,13 @@ import java.util.Iterator;
 import java.util.List;
 import javax.servlet.http.HttpServletRequest;
 import org.apache.commons.codec.binary.Base64;
-import org.opensaml.security.SAMLSignatureProfileValidator;
-import org.opensaml.ws.transport.http.HTTPTransportUtils;
-import org.opensaml.xml.security.SecurityException;
-import org.opensaml.xml.security.SigningUtil;
-import org.opensaml.xml.security.credential.Credential;
-import org.opensaml.xml.signature.SignableXMLObject;
-import org.opensaml.xml.signature.Signature;
-import org.opensaml.xml.signature.SignatureValidator;
-import org.opensaml.xml.validation.ValidationException;
+import org.opensaml.security.credential.Credential;
+import org.opensaml.security.crypto.SigningUtil;
+import org.opensaml.xmlsec.algorithm.AlgorithmSupport;
+import org.opensaml.xmlsec.signature.SignableXMLObject;
+import org.opensaml.xmlsec.signature.Signature;
+import org.opensaml.xmlsec.signature.support.SignatureException;
+import org.opensaml.xmlsec.signature.support.SignatureValidator;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.openexchange.java.Strings;
@@ -78,7 +76,7 @@ import com.openexchange.saml.validation.ValidationFailedReason;
 public class SignatureHelper {
 
     private static final Logger LOG = LoggerFactory.getLogger(SignatureHelper.class);
-    
+
     /**
      * Validates the signature of a {@link SignableXMLObject} with the passed {@link Credential}.
      *
@@ -89,27 +87,24 @@ public class SignatureHelper {
     public static ValidationError validateSignature(SignableXMLObject object, List<Credential> credentials) {
         try {
             Signature signature = object.getSignature();
-            SAMLSignatureProfileValidator profileValidator = new SAMLSignatureProfileValidator();
-            profileValidator.validate(signature);
             validateWithCredentials(credentials, signature);
-        } catch (org.opensaml.xml.validation.ValidationException e) {
+        } catch (SignatureException e) {
             return new ValidationError(ValidationFailedReason.INVALID_SIGNATURE, e.getMessage(), e);
         }
 
         return null;
     }
 
-    private static void validateWithCredentials(List<Credential> credentials, Signature signature) throws ValidationException {
+    private static void validateWithCredentials(List<Credential> credentials, Signature signature) throws SignatureException {
         boolean isValid = false;
-        
+
         Iterator<Credential> iterator = credentials.iterator();
         while (iterator.hasNext()) {
             Credential credential = iterator.next();
-            SignatureValidator signatureValidator = new SignatureValidator(credential);
             try {
-                signatureValidator.validate(signature);
+                SignatureValidator.validate(signature, credential);
                 isValid = true;
-            } catch (org.opensaml.xml.validation.ValidationException e) {
+            } catch (SignatureException e) {
                 if (iterator.hasNext() == false && isValid == false) {
                     throw e;
                 }
@@ -125,8 +120,8 @@ public class SignatureHelper {
      * @return A {@link ValidationError} if signature validation fails or <code>null</code> if the signature is valid
      */
     public static ValidationError validateURISignature(HttpServletRequest httpRequest, List<Credential> credentials) {
-        String sigAlg = httpRequest.getParameter("SigAlg");
-        if (sigAlg == null) {
+        String sigAlgUri = httpRequest.getParameter("SigAlg");
+        if (sigAlgUri == null) {
             return new ValidationError(ValidationFailedReason.INVALID_REQUEST, "Parameter 'SigAlg' is not set");
         }
 
@@ -148,14 +143,16 @@ public class SignatureHelper {
         }
         signedContent.append('&').append(HTTPTransportUtils.getRawQueryStringParameter(queryString, "SigAlg"));
 
-        return getValidationError(credentials, sigAlg, signature, signedContent);
+        return getValidationError(credentials, sigAlgUri, signature, signedContent);
     }
 
-    private static ValidationError getValidationError(List<Credential> credentials, String sigAlg, String signature, StringBuilder signedContent) {
+    private static ValidationError getValidationError(List<Credential> credentials, String sigAlgUri, String signature, StringBuilder signedContent) {
         try {
             boolean isInvalid = true;
+            final boolean isHMAC = AlgorithmSupport.isHMAC(sigAlgUri);
+            final String jcaAlgorithmID = AlgorithmSupport.getAlgorithmID(sigAlgUri);
             for (final Credential credential : credentials) {
-                if (SigningUtil.verifyWithURI(credential, sigAlg, Base64.decodeBase64(signature), signedContent.toString().getBytes("UTF-8"))) {
+                if (SigningUtil.verify(credential, jcaAlgorithmID, isHMAC, Base64.decodeBase64(signature), signedContent.toString().getBytes("UTF-8"))) {
                     isInvalid = false;
                 } else {
                     String fingerprint = Strings.isEmpty(credential.getEntityId()) ? "" : credential.getEntityId();
@@ -163,9 +160,9 @@ public class SignatureHelper {
                 }
             }
             if (isInvalid) {
-                return new ValidationError(ValidationFailedReason.INVALID_SIGNATURE, "The signatures do not match the signed content", new org.opensaml.xml.validation.ValidationException());
+                return new ValidationError(ValidationFailedReason.INVALID_SIGNATURE, "The signatures do not match the signed content");
             }
-        } catch (UnsupportedEncodingException | SecurityException e) {
+        } catch (UnsupportedEncodingException | org.opensaml.security.SecurityException e) {
             return new ValidationError(ValidationFailedReason.INVALID_SIGNATURE, e.getMessage(), e);
         }
 
