@@ -49,8 +49,8 @@
 
 package com.openexchange.saml.validation;
 
-import org.opensaml.saml2.core.Assertion;
-import org.opensaml.saml2.core.Response;
+import org.opensaml.saml.saml2.core.Assertion;
+import org.opensaml.saml.saml2.core.Response;
 
 
 /**
